.. pl_extension documentation master file, created by
   sphinx-quickstart on Mon Apr 16 21:22:43 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pl_extension!
==================================

*pl_extension* is extension to `Pytorch Lightning <https://pytorch-lightning.readthedocs.io/en/latest/>`_ ,
with more useful callbacks and utilities.

.. toctree::
   :maxdepth: 2
   :name: api
   :caption: API Reference

   api_reference


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
